@@ -1,8 +1,10 @@
+pub mod cassandra;
 pub mod dynamodb;
 pub mod mysql;
 pub mod postgres;
 pub mod redis;
 
+pub use cassandra::Cassandra;
 pub use dynamodb::DynamoDB;
 pub use mysql::Mysql;
 pub use postgres::Postgres;
